@@ -45,12 +45,14 @@
 
 #define TOKEN_EXEC_URI_LIST "%U"
 #define TOKEN_EXEC_FILE_LIST "%F"
-#define TOKEN_EXEC_PARENT "%P"
+#define TOKEN_EXEC_LOCATION_PATH "%P" // also parent path
+#define TOKEN_EXEC_LOCATION_URI "%R" //  and uri
 #define TOKEN_EXEC_FILE_NAME "%f"
 #define TOKEN_EXEC_PARENT_NAME "%p"
 #define TOKEN_EXEC_DEVICE "%D"
 #define TOKEN_EXEC_FILE_NO_EXT "%e"
 #define TOKEN_EXEC_LITERAL_PERCENT "%%"
+#define TOKEN_EXEC_XID "%X"
 
 #define TOKEN_LABEL_FILE_NAME "%N" // Leave in for compatibility, same as TOKEN_EXEC_FILE_NAME
 
@@ -73,6 +75,7 @@
 #define KEY_WHITESPACE "EscapeSpaces"
 #define KEY_DOUBLE_ESCAPE_QUOTES "DoubleEscapeQuotes"
 #define KEY_TERMINAL "Terminal"
+#define KEY_URI_SCHEME "UriScheme"
 
 typedef struct _NemoAction NemoAction;
 typedef struct _NemoActionClass NemoActionClass;
@@ -99,9 +102,11 @@ typedef enum {
     TOKEN_FILE_DISPLAY_NAME,
     TOKEN_PARENT_DISPLAY_NAME,
     TOKEN_PARENT_PATH,
+    TOKEN_PARENT_URI,
     TOKEN_DEVICE,
     TOKEN_FILE_DISPLAY_NAME_NO_EXT,
-    TOKEN_LITERAL_PERCENT
+    TOKEN_LITERAL_PERCENT,
+    TOKEN_XID
 } TokenType;
 
 struct _NemoAction {
@@ -128,6 +133,7 @@ struct _NemoAction {
     gboolean escape_space;
     gboolean show_in_blank_desktop;
     gboolean run_in_terminal;
+    gchar *uri_scheme;
 
     gboolean constructing;
 };
@@ -138,12 +144,12 @@ struct _NemoActionClass {
 
 GType         nemo_action_get_type             (void);
 NemoAction   *nemo_action_new                  (const gchar *name, const gchar *path);
-void          nemo_action_activate             (NemoAction *action, GList *selection, NemoFile *parent);
+void          nemo_action_activate             (NemoAction *action, GList *selection, NemoFile *parent, GtkWindow *window);
 
 const gchar  *nemo_action_get_orig_label       (NemoAction *action);
 const gchar  *nemo_action_get_orig_tt          (NemoAction *action);
-gchar        *nemo_action_get_label            (NemoAction *action, GList *selection, NemoFile *parent);
-gchar        *nemo_action_get_tt               (NemoAction *action, GList *selection, NemoFile *parent);
-gboolean      nemo_action_get_visibility       (NemoAction *action, GList *selection, NemoFile *parent, gboolean for_places);
+gchar        *nemo_action_get_label            (NemoAction *action, GList *selection, NemoFile *parent, GtkWindow *window);
+gchar        *nemo_action_get_tt               (NemoAction *action, GList *selection, NemoFile *parent, GtkWindow *window);
+gboolean      nemo_action_get_visibility       (NemoAction *action, GList *selection, NemoFile *parent, gboolean for_places, GtkWindow *window);
 
 #endif /* NEMO_ACTION_H */
