@@ -108,6 +108,8 @@ struct NemoFileDetails
 
 	GList *mime_list; /* If this is a directory, the list of MIME types in it. */
 
+    GHashTable *search_results;
+
 	/* Info you might get from a link (.desktop, .directory or nemo link) */
 	GIcon *custom_icon;
 	char *activation_uri;
@@ -158,10 +160,6 @@ struct NemoFileDetails
 	eel_boolean_bit get_info_failed               : 1;
 	eel_boolean_bit file_info_is_up_to_date       : 1;
 	
-    eel_boolean_bit got_btime                     : 1;
-    eel_boolean_bit get_btime_failed              : 1;
-    eel_boolean_bit btime_is_up_to_date           : 1;
-
 	eel_boolean_bit got_directory_count           : 1;
 	eel_boolean_bit directory_count_failed        : 1;
 	eel_boolean_bit directory_count_is_up_to_date : 1;
