@@ -1143,6 +1143,7 @@ draw_label_text (NemoIconCanvasItem *item,
 		gtk_render_layout (context, cr,
 				   x, text_rect.y0 + details->editable_text_height + LABEL_LINE_SPACING + TEXT_TOP_GAP,
 				   additional_layout);
+        gtk_style_context_restore (context);
 	}
 
 	if (item->details->is_highlighted_as_keyboard_focus) {
@@ -1286,8 +1287,6 @@ real_map_surface (NemoIconCanvasItem *icon_item)
 {
 	EelCanvas *canvas;
 	GdkPixbuf *temp_pixbuf, *old_pixbuf;
-	GtkStyleContext *style;
-	GdkRGBA color;
     cairo_surface_t *surface;
 
 	temp_pixbuf = icon_item->details->pixbuf;
@@ -1303,22 +1302,6 @@ real_map_surface (NemoIconCanvasItem *icon_item)
 		g_object_unref (old_pixbuf);
 	}
 
-	if (icon_item->details->is_highlighted_for_selection
-	    || icon_item->details->is_highlighted_for_drop) {
-		style = gtk_widget_get_style_context (GTK_WIDGET (canvas));
-
-		if (gtk_widget_has_focus (GTK_WIDGET (canvas))) {
-			gtk_style_context_get_background_color (style, GTK_STATE_FLAG_SELECTED, &color);
-		} else {
-			gtk_style_context_get_background_color (style, GTK_STATE_FLAG_ACTIVE, &color);
-		}
-
-		old_pixbuf = temp_pixbuf;
-		temp_pixbuf = eel_create_colorized_pixbuf (temp_pixbuf, &color);
-
-		g_object_unref (old_pixbuf);
-	}
-
     surface = gdk_cairo_surface_create_from_pixbuf (temp_pixbuf,
                                                     gtk_widget_get_scale_factor (GTK_WIDGET (canvas)),
                                                     gtk_widget_get_window (GTK_WIDGET (canvas)));
@@ -1483,9 +1466,6 @@ create_label_layout (NemoIconCanvasItem *item,
     if (item->details->is_pinned) {
         pango_font_description_set_weight (desc, PINNED_TEXT_WEIGHT);
     }
-    else {
-        pango_font_description_set_weight (desc, NORMAL_TEXT_WEIGHT);
-    }
 
 	pango_layout_set_font_description (layout, desc);
 	pango_font_description_free (desc);
