@@ -366,15 +366,15 @@ static void
 custom_app_set (NemoMimeApplicationChooser *chooser,
                 GtkFileChooser             *dialog)
 {
-    gchar *unescaped = gtk_file_chooser_get_filename (dialog);
-    gchar *escaped = eel_str_escape_spaces (unescaped);
+    gchar *unquoted = gtk_file_chooser_get_filename (dialog);
+    gchar *quoted = g_shell_quote (unquoted);
 
-    gtk_entry_set_text (GTK_ENTRY (chooser->details->custom_entry), escaped);
+    gtk_entry_set_text (GTK_ENTRY (chooser->details->custom_entry), quoted);
     gtk_widget_grab_focus (chooser->details->custom_entry);
     gtk_editable_set_position (GTK_EDITABLE (chooser->details->custom_entry), -1);
 
-    g_free (unescaped);
-    g_free (escaped);
+    g_free (unquoted);
+    g_free (quoted);
 }
 
 static char *
