@@ -132,6 +132,7 @@ set_metadata_callback (GObject *source_object,
 					 NULL,
 					 set_metadata_get_info_callback, file);
 	} else {
+        g_printerr ("ERROR SET META:%d %s\n", error->code, error->message);
 		nemo_file_unref (file);
 		g_error_free (error);
 	}
@@ -312,6 +313,15 @@ vfs_file_get_date (NemoFile *file,
 			*date = file->details->mtime;
 		}
 		return TRUE;
+    case NEMO_DATE_TYPE_CREATED:
+        /* Before we have info on a file, the date is unknown. */
+        if (file->details->btime == 0) {
+            return FALSE;
+        }
+        if (date != NULL) {
+            *date = file->details->btime;
+        }
+        return TRUE;
 	case NEMO_DATE_TYPE_TRASHED:
 		/* Before we have info on a file, the date is unknown. */
 		if (file->details->trash_time == 0) {
@@ -351,7 +361,8 @@ vfs_file_get_where_string (NemoFile *file)
     NemoFile *location;
     char *where_string;
 
-    if (!nemo_file_is_in_recent (file)) {
+    if (!nemo_file_is_in_recent (file) &&
+        !nemo_file_is_in_favorites (file)) {
         location = nemo_file_ref (file);
     } else {
         activation_location = nemo_file_get_activation_location (file);
