@@ -36,13 +36,16 @@
 #define NEMO_ACTION_UP_ACCEL "UpAccel"
 #define NEMO_ACTION_UP_ACCEL "UpAccel"
 #define NEMO_ACTION_FORWARD "Forward"
-#define NEMO_ACTION_SHOW_HIDE_TOOLBAR "Show Hide Toolbar"
 #define NEMO_ACTION_SHOW_HIDE_SIDEBAR "Show Hide Sidebar"
+
+#define NEMO_ACTION_SHOW_HIDE_TOOLBAR "Show Hide Toolbar"
+#define NEMO_ACTION_TOOLBAR_ALWAYS_SHOW_PATHBAR "Toolbar Always Show Pathbar"
+#define NEMO_ACTION_TOOLBAR_ALWAYS_SHOW_ENTRY "Toolbar Always Show Entry"
+
 #define NEMO_ACTION_SHOW_HIDE_STATUSBAR "Show Hide Statusbar"
 #define NEMO_ACTION_SHOW_HIDE_MENUBAR "Show Hide Menubar"
 #define NEMO_ACTION_SHOW_HIDE_LOCATION_BAR "Show Hide Location Bar"
 #define NEMO_ACTION_SHOW_HIDE_EXTRA_PANE "Show Hide Extra Pane"
-#define NEMO_ACTION_SHOW_HIDE_LOCATION_ENTRY "Show Hide Location Entry"
 #define NEMO_ACTION_GO_TO_BURN_CD "Go to Burn CD"
 #define NEMO_ACTION_EDIT_LOCATION "Edit Location"
 #define NEMO_ACTION_COMPACT_VIEW "CompactView"
@@ -74,8 +77,6 @@
 #define NEMO_ACTION_LOCATION_PROPERTIES "LocationProperties"
 #define NEMO_ACTION_NO_TEMPLATES "No Templates"
 #define NEMO_ACTION_EMPTY_TRASH "Empty Trash"
-#define NEMO_ACTION_SAVE_SEARCH "Save Search"
-#define NEMO_ACTION_SAVE_SEARCH_AS "Save Search As"
 #define NEMO_ACTION_CUT "Cut"
 #define NEMO_ACTION_LOCATION_CUT "LocationCut"
 #define NEMO_ACTION_COPY "Copy"
