@@ -86,7 +86,7 @@ static void     real_merge_menus                                  (NemoView
 static void     real_update_menus                                 (NemoView        *view);
 static void     nemo_desktop_icon_view_update_icon_container_fonts  (NemoDesktopIconView      *view);
 static void     font_changed_callback                             (gpointer                callback_data);
-static void     nemo_desktop_icon_view_constructed (NemoDesktopIconView *desktop_icon_view);
+static void     nemo_desktop_icon_view_constructed (GObject *object);
 
 G_DEFINE_TYPE (NemoDesktopIconView, nemo_desktop_icon_view, NEMO_TYPE_ICON_VIEW)
 
@@ -193,13 +193,13 @@ real_add_file (NemoView *view, NemoFile *file, NemoDirectory *directory)
 
     g_assert (directory == nemo_view_get_model (view));
 
-    icon_view = NEMO_ICON_VIEW (view);
-    icon_container = get_icon_container (icon_view);
-
     if (!should_show_file_on_current_monitor (view, file)) {
         return;
     }
 
+    icon_view = NEMO_ICON_VIEW (view);
+    icon_container = get_icon_container (icon_view);
+
     if (nemo_icon_container_add (icon_container, NEMO_ICON_CONTAINER_ICON_DATA (file))) {
         nemo_file_ref (file);
     }
@@ -505,12 +505,15 @@ nemo_desktop_icon_view_init (NemoDesktopIconView *desktop_icon_view)
 }
 
 static void
-nemo_desktop_icon_view_constructed (NemoDesktopIconView *desktop_icon_view)
+nemo_desktop_icon_view_constructed (GObject *object)
 {
+    NemoDesktopIconView *desktop_icon_view;
     NemoIconContainer *icon_container;
     GtkAllocation allocation;
     GtkAdjustment *hadj, *vadj;
 
+    desktop_icon_view = NEMO_DESKTOP_ICON_VIEW (object);
+
     G_OBJECT_CLASS (nemo_desktop_icon_view_parent_class)->constructed (G_OBJECT (desktop_icon_view));
 
     if (desktop_directory == NULL) {
