@@ -985,6 +985,8 @@ nemo_icon_view_begin_loading (NemoView *view)
 	uri = nemo_file_get_uri (file);
 	icon_container = GTK_WIDGET (get_icon_container (icon_view));
 
+    nemo_icon_container_set_ok_to_load_deferred_attrs (NEMO_ICON_CONTAINER (icon_container), FALSE);
+
 	nemo_icon_container_begin_loading (NEMO_ICON_CONTAINER (icon_container));
 
 	nemo_icon_container_set_allow_moves (NEMO_ICON_CONTAINER (icon_container),
@@ -1086,11 +1088,9 @@ nemo_icon_view_end_loading (NemoView *view,
 	icon_container = GTK_WIDGET (get_icon_container (icon_view));
 	nemo_icon_container_end_loading (NEMO_ICON_CONTAINER (icon_container), all_files_seen);
 
-    nemo_icon_container_update_selection (NEMO_ICON_CONTAINER (icon_container));
-
 	monitor = nemo_clipboard_monitor_get ();
 	info = nemo_clipboard_monitor_get_clipboard_info (monitor);
-
+    nemo_icon_container_set_ok_to_load_deferred_attrs (NEMO_ICON_CONTAINER (icon_container), TRUE);
 	icon_view_notify_clipboard_info (monitor, info, icon_view);
 }
 
@@ -1763,7 +1763,9 @@ nemo_icon_view_compare_files (NemoIconView   *icon_view,
 		(a, b, icon_view->details->sort->sort_type,
 		 /* Use type-unsafe cast for performance */
 		 nemo_view_should_sort_directories_first ((NemoView *)icon_view),
-		 icon_view->details->sort_reversed);
+		 nemo_view_should_sort_favorites_first ((NemoView *)icon_view),
+		 icon_view->details->sort_reversed,
+         NULL);
 }
 
 static int
@@ -1868,8 +1870,6 @@ selection_changed_callback (NemoIconContainer *container,
 	g_assert (NEMO_IS_ICON_VIEW (icon_view));
 	g_assert (container == get_icon_container (icon_view));
 
-    nemo_icon_container_update_selection (container);
-
 	nemo_view_notify_selection_changed (NEMO_VIEW (icon_view));
 }
 
@@ -2165,6 +2165,19 @@ nemo_icon_view_sort_directories_first_changed (NemoView *directory_view)
 	}
 }
 
+static void
+nemo_icon_view_sort_favorites_first_changed (NemoView *directory_view)
+{
+	NemoIconView *icon_view;
+
+	icon_view = NEMO_ICON_VIEW (directory_view);
+
+	if (nemo_icon_view_using_auto_layout (icon_view)) {
+		nemo_icon_container_sort
+			(get_icon_container (icon_view));
+	}
+}
+
 static gboolean
 icon_view_can_accept_item (NemoIconContainer *container,
 			   NemoFile *target_item,
@@ -2717,6 +2730,7 @@ nemo_icon_view_class_init (NemoIconViewClass *klass)
         nemo_view_class->merge_menus = nemo_icon_view_merge_menus;
         nemo_view_class->unmerge_menus = nemo_icon_view_unmerge_menus;
         nemo_view_class->sort_directories_first_changed = nemo_icon_view_sort_directories_first_changed;
+        nemo_view_class->sort_favorites_first_changed = nemo_icon_view_sort_favorites_first_changed;
         nemo_view_class->start_renaming_file = nemo_icon_view_start_renaming_file;
         nemo_view_class->update_menus = nemo_icon_view_update_menus;
 	nemo_view_class->using_manual_layout = nemo_icon_view_using_manual_layout;
@@ -2812,9 +2826,6 @@ nemo_icon_view_supports_uri (const char *uri,
 	if (file_type == G_FILE_TYPE_DIRECTORY) {
 		return TRUE;
 	}
-	if (strcmp (mime_type, NEMO_SAVED_SEARCH_MIMETYPE) == 0){
-		return TRUE;
-	}
 	if (g_str_has_prefix (uri, "trash:")) {
 		return TRUE;
 	}
