@@ -224,7 +224,7 @@ editable_event_after_callback (GtkEntry *entry,
 	 * typing when the directory is large. Only trigger the expand
 	 * when we type a key that would have inserted characters.
 	 */
-	if (position_and_selection_are_at_end (editable)) {
+	if (position_and_selection_are_at_end (editable) && keyevent->keyval != GDK_KEY_Escape) {
 		if (entry_would_have_inserted_characters (keyevent)) {
 			if (location_entry->details->idle_id == 0) {
 				location_entry->details->idle_id = g_idle_add (try_to_expand_path, location_entry);
@@ -321,22 +321,28 @@ static void
 nemo_location_entry_activate (GtkEntry *entry)
 {
 	NemoLocationEntry *loc_entry;
-	const gchar *entry_text;
+	gchar *entry_text;
 	gchar *full_path, *uri_scheme = NULL;
 
 	loc_entry = NEMO_LOCATION_ENTRY (entry);
-	entry_text = gtk_entry_get_text (entry);
+	entry_text = g_strdup (gtk_entry_get_text (entry));
 
 	if (entry_text != NULL && *entry_text != '\0') {
 		uri_scheme = g_uri_parse_scheme (entry_text);
 
-		if (!g_path_is_absolute (entry_text) && uri_scheme == NULL && entry_text[0] != '~') {
-			/* Fix non absolute paths */
-			full_path = g_build_filename (loc_entry->details->current_directory, entry_text, NULL);
-			gtk_entry_set_text (entry, full_path);
-			g_free (full_path);
+              if (!g_path_is_absolute (entry_text) && uri_scheme == NULL && entry_text[0] != '~') {
+                  g_strstrip (entry_text); 
+                  if (entry_text[0] == '/') {
+                    gtk_entry_set_text (entry, entry_text);
+                  } else {
+                    /* Fix non absolute paths */
+                    full_path = g_build_filename (loc_entry->details->current_directory, entry_text, NULL);
+                    gtk_entry_set_text (entry, full_path);
+                    g_free (full_path);
+                  }
 		}
 
+        g_free (entry_text);
 		g_free (uri_scheme);
 	}
 
@@ -385,12 +391,12 @@ nemo_location_entry_set_secondary_action (NemoLocationEntry *entry,
 	case NEMO_LOCATION_ENTRY_ACTION_CLEAR:
 		gtk_entry_set_icon_from_icon_name (GTK_ENTRY (entry), 
 						   GTK_ENTRY_ICON_SECONDARY,
-						   "edit-clear");
+						   "edit-clear-symbolic");
 		break;
 	case NEMO_LOCATION_ENTRY_ACTION_GOTO:
 		gtk_entry_set_icon_from_icon_name (GTK_ENTRY (entry),
 						   GTK_ENTRY_ICON_SECONDARY,
-						   "go-next");
+						   "go-next-symbolic");
 		break;
 	default:
 		g_assert_not_reached ();
