@@ -43,6 +43,7 @@
 #include "nemo-window-private.h"
 #include "nemo-window-slot.h"
 #include "nemo-statusbar.h"
+#include "nemo-notebook.h"
 
 #include <libnemo-private/nemo-dbus-manager.h>
 #include <libnemo-private/nemo-directory-private.h>
@@ -55,6 +56,7 @@
 #include <libnemo-private/nemo-ui-utilities.h>
 #include <libnemo-private/nemo-undo-manager.h>
 #include <libnemo-private/nemo-thumbnails.h>
+#include <libnemo-private/nemo-search-engine-advanced.h>
 #include <libnemo-extension/nemo-menu-provider.h>
 
 #define DEBUG_FLAG NEMO_DEBUG_APPLICATION
@@ -65,12 +67,12 @@
 #include <pwd.h>
 #include <fcntl.h>
 #include <errno.h>
+#include <gdk/gdkx.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-stock-dialogs.h>
-#include <libnotify/notify.h>
 
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 
@@ -84,6 +86,13 @@
 
 #define NEMO_ACCEL_MAP_SAVE_DELAY 30
 
+/* Disable the self-check functionality */
+#define NEMO_OMIT_SELF_CHECK "omit"
+
+#define NEMO_NOTIFICATION_UNMOUNT_ICON_NAME  "media-removable"
+#define NEMO_NOTIFICATION_UNMOUNT_ID_PENDING "unmount-pending"
+#define NEMO_NOTIFICATION_UNMOUNT_ID_DONE    "unmount-done"
+
 static void     mount_removed_callback            (GVolumeMonitor            *monitor,
 						   GMount                    *mount,
 						   NemoMainApplication       *application);
@@ -100,61 +109,67 @@ struct _NemoMainApplicationPriv {
 	NemoFreedesktopDBus *fdb_manager;
 
 	gchar *geometry;
-
-    NotifyNotification *unmount_notify;
 };
 
+static void
+nemo_main_application_send_notification (NemoApplication *application,
+                                         const gchar *title,
+                                         const gchar *body,
+                                         const gchar *icon_name,
+                                         const gchar *notification_id,
+                                         const GNotificationPriority prio)
+{
+	NemoMainApplication *app = NEMO_MAIN_APPLICATION (application);
+	GNotification *notification;
+	GIcon *icon;
+
+	icon = g_themed_icon_new (icon_name);
+	notification = g_notification_new (title);
+	g_notification_set_body (notification, body);
+	g_notification_set_icon (notification, icon);
+	g_notification_set_priority (notification, prio);
+
+	g_application_send_notification (G_APPLICATION (app), notification_id, notification);
+
+	g_object_unref (notification);
+	g_object_unref (icon);
+}
+
 static void
 nemo_main_application_notify_unmount_done (NemoApplication *application,
                                            const gchar     *message)
 {
-    NemoMainApplication *app = NEMO_MAIN_APPLICATION (application);
+	NemoMainApplication *app = NEMO_MAIN_APPLICATION (application);
+	gchar **strings;
 
-    if (app->priv->unmount_notify) {
-        notify_notification_close (app->priv->unmount_notify, NULL);
-        g_clear_object (&app->priv->unmount_notify);
-    }
+	// remove notification for pending unmount state
+	g_application_withdraw_notification (G_APPLICATION (app), NEMO_NOTIFICATION_UNMOUNT_ID_PENDING);
 
-    if (message != NULL) {
-        NotifyNotification *unplug;
-        gchar **strings;
+	g_return_if_fail (message != NULL);
+	strings = g_strsplit (message, "\n", 2);
 
-        strings = g_strsplit (message, "\n", 0);
-        unplug = notify_notification_new (strings[0], strings[1],
-                                          "media-removable");
-
-        notify_notification_show (unplug, NULL);
-        g_object_unref (unplug);
-        g_strfreev (strings);
-    }
+	nemo_main_application_send_notification (application, strings[0], strings[1],
+	                                         NEMO_NOTIFICATION_UNMOUNT_ICON_NAME,
+	                                         NEMO_NOTIFICATION_UNMOUNT_ID_DONE,
+	                                         G_NOTIFICATION_PRIORITY_NORMAL);
+	
+	g_strfreev (strings);
 }
 
 static void
 nemo_main_application_notify_unmount_show (NemoApplication *application,
                                            const gchar     *message)
 {
-    NemoMainApplication *app = NEMO_MAIN_APPLICATION (application);
+	gchar **strings;
 
-    gchar **strings;
+	g_return_if_fail (message != NULL);
+	strings = g_strsplit (message, "\n", 2);
 
-    strings = g_strsplit (message, "\n", 0);
-
-    if (!app->priv->unmount_notify) {
-        app->priv->unmount_notify = notify_notification_new (strings[0], strings[1],
-                                                             "media-removable");
-
-        notify_notification_set_hint (app->priv->unmount_notify,
-                                      "transient", g_variant_new_boolean (TRUE));
-        notify_notification_set_urgency (app->priv->unmount_notify,
-                                         NOTIFY_URGENCY_CRITICAL);
-    } else {
-        notify_notification_update (app->priv->unmount_notify,
-                                    strings[0], strings[1],
-                                    "media-removable");
-    }
-
-    notify_notification_show (app->priv->unmount_notify, NULL);
-    g_strfreev (strings);
+	nemo_main_application_send_notification (application, strings[0], strings[1],
+	                                         NEMO_NOTIFICATION_UNMOUNT_ICON_NAME,
+	                                         NEMO_NOTIFICATION_UNMOUNT_ID_PENDING,
+	                                         G_NOTIFICATION_PRIORITY_URGENT);
+	g_strfreev (strings);
 }
 
 static void
@@ -391,13 +406,65 @@ open_tabs (NemoMainApplication *application,
     }
 }
 
+static void
+open_tabs_in_existing_window (NemoMainApplication *application,
+                              GFile **locations,
+                              guint n_files,
+                              GdkScreen *screen,
+                              const char *geometry)
+{
+    gchar *uri;
+
+    GList *list_copy;
+    GList *l;
+
+    list_copy = g_list_copy (gtk_application_get_windows (GTK_APPLICATION (&application->parent)));
+    for (l = list_copy; l != NULL; l = l->next) {
+        if (NEMO_IS_WINDOW (l->data)) {
+            NemoWindow *window;
+
+            window = NEMO_WINDOW (l->data);
+
+            /* open all locations */
+            for (int i = 1; i <= n_files; i++) {
+                /* open tabs in reverse order because each
+                 * tab is opened before the previous one */
+                guint tab = n_files - i;
+                uri = g_file_get_uri (locations[tab]);
+                g_debug ("Opening new tab at uri %s\n", uri);
+                nemo_window_go_to_tab (window, locations[tab]);
+                g_free(uri);
+            }
+
+            /* go to the last tab we opened */
+            NemoWindowPane *pane;
+
+            pane = nemo_window_get_active_pane (window);
+            nemo_notebook_set_current_page_relative (NEMO_NOTEBOOK (pane->notebook), n_files);
+
+            /* Don't use `gtk_window_present()`, as the window manager will ignore this window's focus request and try
+             * to just mark it urgent instead (flashing in the window list for example). */
+            gtk_window_present_with_time (GTK_WINDOW (window),
+                                          gdk_x11_get_server_time (gtk_widget_get_window (GTK_WIDGET (window))));
+
+          break;
+        }
+    }
+    if (l == NULL) {
+        /* no existing window was found, so open a new window */
+        open_tabs (application, locations, n_files, screen, geometry);
+    }
+    g_list_free (list_copy);
+}
+
 static void
 open_windows (NemoMainApplication *application,
 	      GFile **files,
 	      gint n_files,
 	      GdkScreen *screen,
 	      const char *geometry,
-	      gboolean open_in_tabs)
+	      gboolean open_in_tabs,
+	      gboolean open_in_existing_window)
 {
 	gint i;
 
@@ -405,7 +472,10 @@ open_windows (NemoMainApplication *application,
 		/* Open a window pointing at the default location. */
 		open_window (application, NULL, screen, geometry);
 	} else {
-		if (open_in_tabs) {
+		if (open_in_existing_window) {
+			/* Open one tab at each requested location in an existing window */
+			open_tabs_in_existing_window (application, files, n_files, screen, geometry);
+		} else if (open_in_tabs) {
 			/* Open one window with one tab at each requested location */
 			open_tabs (application, files, n_files, screen, geometry);
 		} else {
@@ -457,26 +527,31 @@ nemo_main_application_open (GApplication *app,
 
 	gboolean open_in_tabs = FALSE;
 	gchar *geometry = NULL;
+	gboolean open_in_existing_window = strcmp (options, "EXISTING_WINDOW") == 0;
 	const char splitter = '=';
 
 	g_debug ("Open called on the GApplication instance; %d files", n_files);
 
-	/* Check if local command line passed --geometry or --tabs */
-	if (strlen (options) > 0) {
-		gchar** split_options = g_strsplit (options, &splitter, 2);
-		if (strcmp (split_options[0], "NULL") != 0) {
-			geometry = g_strdup (split_options[0]);
+	if (!open_in_existing_window) {
+		/* Check if local command line passed --geometry or --tabs */
+		if (strlen (options) > 0) {
+			gchar** split_options = g_strsplit (options, &splitter, 2);
+			if (strcmp (split_options[0], "NULL") != 0) {
+				geometry = g_strdup (split_options[0]);
+			}
+			sscanf (split_options[1], "%d", &open_in_tabs);
+			g_strfreev (split_options);
 		}
-		sscanf (split_options[1], "%d", &open_in_tabs);
-		g_strfreev (split_options);
 	}
 
-	DEBUG ("Open called on the GApplication instance; %d files, open in tabs: %s, geometry: '%s'",
+	DEBUG ("Open called on the GApplication instance; %d files, open in tabs: %s, geometry: '%s',"
+           "open in existing window: %s",
            n_files,
            open_in_tabs ? "yes" : "no",
-           geometry ? geometry : "none");
+           geometry ? geometry : "none",
+           open_in_existing_window ? "yes" : "no");
 
-	open_windows (self, files, n_files, gdk_screen_get_default (), geometry, open_in_tabs);
+	open_windows (self, files, n_files, gdk_screen_get_default (), geometry, open_in_tabs, open_in_existing_window);
 
     g_clear_pointer (&geometry, g_free);
 }
@@ -504,6 +579,8 @@ nemo_main_application_finalize (GObject *object)
     g_clear_object (&application->priv->dbus_manager);
     g_clear_object (&application->priv->fdb_manager);
 
+    free_search_helpers ();
+
     G_OBJECT_CLASS (nemo_main_application_parent_class)->finalize (object);
 }
 
@@ -570,6 +647,7 @@ nemo_main_application_local_command_line (GApplication *application,
 	gboolean version = FALSE;
 	gboolean browser = FALSE;
 	gboolean open_in_tabs = FALSE;
+	gboolean open_in_existing_window = FALSE;
 	gboolean kill_shell = FALSE;
 	gboolean no_default_window = FALSE;
     gboolean no_desktop_ignored = FALSE;
@@ -598,6 +676,8 @@ nemo_main_application_local_command_line (GApplication *application,
           N_("Ignored argument - left for compatibility only."), NULL },
 		{ "tabs", 't', 0, G_OPTION_ARG_NONE, &open_in_tabs,
 		  N_("Open URIs in tabs."), NULL },
+		{ "existing-window", 0, 0, G_OPTION_ARG_NONE, &open_in_existing_window,
+		  N_("Open URIs in an existing window."), NULL },
 		{ "fix-cache", '\0', 0, G_OPTION_ARG_NONE, &fix_cache,
 		  N_("Repair the user thumbnail cache - this can be useful if you're having trouble with file thumbnails.  Must be run as root"), NULL },
         { "debug", 0, 0, G_OPTION_ARG_NONE, &debug,
@@ -651,9 +731,14 @@ nemo_main_application_local_command_line (GApplication *application,
 	}
 
     if (fix_cache) {
-        if (geteuid () != 0) {
+        if (nemo_user_is_root () && nemo_treating_root_as_normal ()) {
+            g_printerr ("Ignoring --fix-cache as root-is-normal setting is true and this "
+                        "check is probably unnecessary.\n");
+        } else
+        if (!nemo_user_is_root ()) {
             g_printerr ("The --fix-cache option must be run with sudo or as the root user.\n");
-        } else {
+        } else
+        {
             gnome_desktop_thumbnail_cache_fix_permissions ();
             g_print ("User thumbnail cache successfully repaired.\n");
         }
@@ -733,13 +818,17 @@ post_registration:
 		files[0] = g_file_new_for_path (g_get_home_dir ());
 		files[1] = NULL;
 	}
-	/* Invoke "Open" to create new windows */
+	/* Invoke "Open" to open in existing window or create new windows */
 	if (len > 0) {
 		gchar* concatOptions = g_malloc0(64);
-		if (self->priv->geometry == NULL) {
-			g_snprintf (concatOptions, 64, "NULL=%d", open_in_tabs);
+		if (open_in_existing_window) {
+			g_stpcpy (concatOptions, "EXISTING_WINDOW");
 		} else {
-			g_snprintf (concatOptions, 64, "%s=%d", self->priv->geometry, open_in_tabs);
+			if (self->priv->geometry == NULL) {
+				g_snprintf (concatOptions, 64, "NULL=%d", open_in_tabs);
+			} else {
+				g_snprintf (concatOptions, 64, "%s=%d", self->priv->geometry, open_in_tabs);
+			}
 		}
 		g_application_open (application, files, len, concatOptions);
 		g_free (concatOptions);
@@ -882,7 +971,6 @@ nemo_main_application_get_singleton (void)
     return nemo_application_initialize_singleton (NEMO_TYPE_MAIN_APPLICATION,
                                                   "application-id", "org.Nemo",
                                                   "flags", G_APPLICATION_HANDLES_OPEN,
-                                                  "inactivity-timeout", 30 * 1000, // seconds
                                                   "register-session", TRUE,
                                                   NULL);
 }
